__version__="0.3.4"
def sum(a,b):
    return a+b
def sub(a,b):
    return a-b
def mul(a,b):
    return a*b
def div(a,b):
    return a/b
def exp(a,b):
    return a**b
def complex(a,b):
    c,d='i+','j'
    return str(a)+c+str(b)+d

